@@ -18,16 +18,17 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
 #ifndef __GTK_PAPER_SIZE_H__
 #define __GTK_PAPER_SIZE_H__
 
-#include <glib-object.h>
+
 #include <gtk/gtkenums.h>
 
+
 G_BEGIN_DECLS
 
 typedef struct _GtkPaperSize GtkPaperSize;
@@ -35,12 +36,53 @@ typedef struct _GtkPaperSize GtkPaperSize;
 #define GTK_TYPE_PAPER_SIZE    (gtk_paper_size_get_type ())
 
 /* Common names, from PWG 5101.1-2002 PWG: Standard for Media Standardized Names */
+/**
+ * GTK_PAPER_NAME_A3:
+ *
+ * Name for the A4 paper size.
+ */
 #define GTK_PAPER_NAME_A3 "iso_a3"
+
+/**
+ * GTK_PAPER_NAME_A4:
+ *
+ * Name for the A4 paper size.
+ */
 #define GTK_PAPER_NAME_A4 "iso_a4"
+
+/**
+ * GTK_PAPER_NAME_A5:
+ *
+ * Name for the A5 paper size.
+ */
 #define GTK_PAPER_NAME_A5 "iso_a5"
+
+/**
+ * GTK_PAPER_NAME_B5:
+ *
+ * Name for the B5 paper size.
+ */
 #define GTK_PAPER_NAME_B5 "iso_b5"
+
+/**
+ * GTK_PAPER_NAME_LETTER:
+ *
+ * Name for the Letter paper size.
+ */
 #define GTK_PAPER_NAME_LETTER "na_letter"
+
+/**
+ * GTK_PAPER_NAME_EXECUTIVE:
+ *
+ * Name for the Executive paper size.
+ */
 #define GTK_PAPER_NAME_EXECUTIVE "na_executive"
+
+/**
+ * GTK_PAPER_NAME_LEGAL:
+ *
+ * Name for the Legal paper size.
+ */
 #define GTK_PAPER_NAME_LEGAL "na_legal"
 
 GType gtk_paper_size_get_type (void) G_GNUC_CONST;
