@@ -17,14 +17,15 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_TREE_MODEL_H__
 #define __GTK_TREE_MODEL_H__
 
 #include <glib-object.h>
 
-/* Not needed, retained for compatibility -Yosh */
-#include <gtk/gtkobject.h>
-
 G_BEGIN_DECLS
 
 #define GTK_TYPE_TREE_MODEL            (gtk_tree_model_get_type ())
@@ -80,11 +81,11 @@ struct _GtkTreeModelIface
 					  gint         *new_order);
 
   /* Virtual Table */
-  GtkTreeModelFlags (* get_flags)  (GtkTreeModel *tree_model);   
+  GtkTreeModelFlags (* get_flags)  (GtkTreeModel *tree_model);
 
   gint         (* get_n_columns)   (GtkTreeModel *tree_model);
   GType        (* get_column_type) (GtkTreeModel *tree_model,
-				    gint          index);
+				    gint          index_);
   gboolean     (* get_iter)        (GtkTreeModel *tree_model,
 				    GtkTreeIter  *iter,
 				    GtkTreePath  *path);
@@ -96,6 +97,8 @@ struct _GtkTreeModelIface
 				    GValue       *value);
   gboolean     (* iter_next)       (GtkTreeModel *tree_model,
 				    GtkTreeIter  *iter);
+  gboolean     (* iter_previous)   (GtkTreeModel *tree_model,
+				    GtkTreeIter  *iter);
   gboolean     (* iter_children)   (GtkTreeModel *tree_model,
 				    GtkTreeIter  *iter,
 				    GtkTreeIter  *parent);
@@ -123,17 +126,20 @@ GtkTreePath *gtk_tree_path_new_from_string  (const gchar       *path);
 GtkTreePath *gtk_tree_path_new_from_indices (gint               first_index,
 					     ...);
 gchar       *gtk_tree_path_to_string        (GtkTreePath       *path);
-#define gtk_tree_path_new_root() gtk_tree_path_new_first()
 GtkTreePath *gtk_tree_path_new_first        (void);
 void         gtk_tree_path_append_index     (GtkTreePath       *path,
-					     gint               index);
+					     gint               index_);
 void         gtk_tree_path_prepend_index    (GtkTreePath       *path,
-					     gint               index);
+					     gint               index_);
 gint         gtk_tree_path_get_depth        (GtkTreePath       *path);
 gint        *gtk_tree_path_get_indices      (GtkTreePath       *path);
+
+gint        *gtk_tree_path_get_indices_with_depth (GtkTreePath *path,
+						   gint        *depth);
+
 void         gtk_tree_path_free             (GtkTreePath       *path);
 GtkTreePath *gtk_tree_path_copy             (const GtkTreePath *path);
-GType        gtk_tree_path_get_type         (void);
+GType        gtk_tree_path_get_type         (void) G_GNUC_CONST;
 gint         gtk_tree_path_compare          (const GtkTreePath *a,
 					     const GtkTreePath *b);
 void         gtk_tree_path_next             (GtkTreePath       *path);
@@ -151,12 +157,14 @@ gboolean     gtk_tree_path_is_descendant    (GtkTreePath       *path,
  * want to call gtk_tree_row_reference_new.
  */
 
+GType                gtk_tree_row_reference_get_type (void) G_GNUC_CONST;
 GtkTreeRowReference *gtk_tree_row_reference_new       (GtkTreeModel        *model,
 						       GtkTreePath         *path);
 GtkTreeRowReference *gtk_tree_row_reference_new_proxy (GObject             *proxy,
 						       GtkTreeModel        *model,
 						       GtkTreePath         *path);
 GtkTreePath         *gtk_tree_row_reference_get_path  (GtkTreeRowReference *reference);
+GtkTreeModel        *gtk_tree_row_reference_get_model (GtkTreeRowReference *reference);
 gboolean             gtk_tree_row_reference_valid     (GtkTreeRowReference *reference);
 GtkTreeRowReference *gtk_tree_row_reference_copy      (GtkTreeRowReference *reference);
 void                 gtk_tree_row_reference_free      (GtkTreeRowReference *reference);
@@ -170,17 +178,17 @@ void                 gtk_tree_row_reference_reordered (GObject     *proxy,
 						       GtkTreePath *path,
 						       GtkTreeIter *iter,
 						       gint        *new_order);
-						       
+
 /* GtkTreeIter operations */
 GtkTreeIter *     gtk_tree_iter_copy             (GtkTreeIter  *iter);
 void              gtk_tree_iter_free             (GtkTreeIter  *iter);
-GType             gtk_tree_iter_get_type         (void);
+GType             gtk_tree_iter_get_type         (void) G_GNUC_CONST;
 
 GType             gtk_tree_model_get_type        (void) G_GNUC_CONST;
 GtkTreeModelFlags gtk_tree_model_get_flags       (GtkTreeModel *tree_model);
 gint              gtk_tree_model_get_n_columns   (GtkTreeModel *tree_model);
 GType             gtk_tree_model_get_column_type (GtkTreeModel *tree_model,
-						  gint          index);
+						  gint          index_);
 
 
 /* Iterator movement */
@@ -192,7 +200,6 @@ gboolean          gtk_tree_model_get_iter_from_string (GtkTreeModel *tree_model,
 						       const gchar  *path_string);
 gchar *           gtk_tree_model_get_string_from_iter (GtkTreeModel *tree_model,
                                                        GtkTreeIter  *iter);
-#define gtk_tree_model_get_iter_root(tree_model, iter) gtk_tree_model_get_iter_first(tree_model, iter)
 gboolean          gtk_tree_model_get_iter_first  (GtkTreeModel *tree_model,
 						  GtkTreeIter  *iter);
 GtkTreePath *     gtk_tree_model_get_path        (GtkTreeModel *tree_model,
@@ -201,6 +208,8 @@ void              gtk_tree_model_get_value       (GtkTreeModel *tree_model,
 						  GtkTreeIter  *iter,
 						  gint          column,
 						  GValue       *value);
+gboolean          gtk_tree_model_iter_previous   (GtkTreeModel *tree_model,
+						  GtkTreeIter  *iter);
 gboolean          gtk_tree_model_iter_next       (GtkTreeModel *tree_model,
 						  GtkTreeIter  *iter);
 gboolean          gtk_tree_model_iter_children   (GtkTreeModel *tree_model,
@@ -233,7 +242,6 @@ void              gtk_tree_model_foreach         (GtkTreeModel            *model
 						  GtkTreeModelForeachFunc  func,
 						  gpointer                 user_data);
 
-
 /* Signals */
 void gtk_tree_model_row_changed           (GtkTreeModel *tree_model,
 					   GtkTreePath  *path,
@@ -251,9 +259,6 @@ void gtk_tree_model_rows_reordered        (GtkTreeModel *tree_model,
 					   GtkTreeIter  *iter,
 					   gint         *new_order);
 
-
-
-
 G_END_DECLS
 
 #endif /* __GTK_TREE_MODEL_H__ */
